import { Metadata, Http } from '@zeedhi/core';
import { Modal, ModalService } from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class AFConfSupplierModalController {
  private AFConfSupplierModal!: Modal;

  public async createAFConfSupplierModal() {
    this.AFConfSupplierModal = await ModalService.createFromJson('/modals/aFConfSupplierGridModal', true);
  }

  public destroyAFConfSupplierModal() {
    this.AFConfSupplierModal?.destroy();
  }

  public async openAFConfSupplierModal({ component }, seriesData) {
    const props = component.options.props;
    const gridRoute = props.gridRoute;
    await this.AFConfSupplierModal.show();
    const gridGroup = Metadata.getInstance<TekGrid>('aFConfSupplierGridGroup');
    gridGroup.title = `${component.options.fullTitle.text} > ${seriesData.name}`;
    
    let queryString = 'requestType=FilterData';
    queryString += `&OPERADOR=${seriesData.CDOPERADOR}`;
    queryString += `&IDCONFRECEBIMENTO=${seriesData.IDCONFRECEBIMENTO}`;
    queryString += `&NMESTADO=${seriesData.ESTADO}`;
    queryString += `&NMREGIAOGEO=${seriesData.REGIAO}`;
    
    Http.get(`/${gridRoute}?${queryString}`).then(({ data }) => {
      gridGroup.datasource.updateData(data.dataset.aFConfSupplierGridGroup);
    });
  }

  public closeAFConfSupplierModalModal() {
    this.AFConfSupplierModal.hide();
  }
}
